# Changelogs

## Latest Changes

## 0.0.2

### Documents

- :page_facing_up: docs: update README and deps package on pyproject. (_2023-09-08_)

### Build & Workflow

- :toolbox: build: change install deps package GitHub workflow. (_2023-09-08_)

## 0.0.1

### Features

- :dart: feat: first initial the main code to this repo. (_2023-09-08_)

### Code Changes

- :construction: refactored: change version of inital stage to 0.0.0. (_2023-09-08_)
- :construction: refactor: Initial commit (_2023-09-08_)

### Documents

- :page_facing_up: docs: edit name in README file and remove un-use deps package. (_2023-09-08_)

### Build & Workflow

- :toolbox: build: add GitHub workflows for test and publish. (_2023-09-08_)

